import path from 'path'
import fs from 'fs-extra'
import findWorkspaceRoot from 'find-yarn-workspace-root'
import { run } from '@toptal/davinci-cli-shared'

export const getRootDir = findWorkspaceRoot

export const getPackageName = config => config.name

export const readPackageJson = folder => {
  const packageJsonFile = path.join(folder, 'package.json')

  const configData = fs.readFileSync(packageJsonFile)
  let config

  try {
    config = JSON.parse(configData)
  } catch (e) {
    console.warn(
      `package.json file from ${folder} can't be parsed as valid JSON. Error: `,
      e
    )
  }

  return config
}

export const installDependencies = folder =>
  run('yarn', ['install'], { cwd: folder })

export default {
  getRootDir: findWorkspaceRoot,
  readPackageJson,
  getPackageName,
  installDependencies,
}
